Heard enum

What the caller heard on the wire since the last offer to a Stabilizer.

Inheritance
Available extensions

Values

reading → const Heard

A reading came out of a parse.

const Heard('reading')
noise → const Heard

Bytes arrived but produced no reading. The scale is there.

const Heard('noise')
silence → const Heard

Nothing arrived at all.

const Heard('silence')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Heard>
A constant List of the values in this enum, in order of their declaration.