ScaleProtocol enum

Inheritance
Available extensions

Values

generic → const ScaleProtocol

A line with a number somewhere in it; ~ or M means motion.

const ScaleProtocol('generic')
cas → const ScaleProtocol

ST,GS,+ 1.234kg.

const ScaleProtocol('cas')
massaK → const ScaleProtocol

$ 1.234.

const ScaleProtocol('massa_k')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ScaleProtocol>
A constant List of the values in this enum, in order of their declaration.